@@ -234,8 +234,13 @@ def dispatch(argv):
     # Take action based on 'core' options and the 'tasks' found
     for context in tasks:
         kwargs = {}
-        for name, arg in six.iteritems(context.args):
-            kwargs[name] = arg.value
+        for _, arg in six.iteritems(context.args):
+            # Use the arg obj's internal name - not what was necessarily given
+            # on the CLI. (E.g. --my-option vs --my_option for
+            # mytask(my_option=xxx) requires this.)
+            # TODO: store 'given' name somewhere in case somebody wants to see
+            # it when handling args.
+            kwargs[arg.name] = arg.value
         try:
             # TODO: allow swapping out of Executor subclasses based on core
             # config options
