@@ -3,13 +3,16 @@ from invoke.tasks import task
 
 @task(aliases=('bar', 'otherbar'))
 def foo():
+    """
+    Foo the bar.
+    """
     pass
 
 @task(default=True)
 def biz():
     pass
 
-@task(help={'why': 'Motive'})
+@task(help={'why': 'Motive', 'who': 'Who to punch'})
 def punch(who, why):
     pass
 
@@ -24,3 +27,7 @@ def two_positionals(pos1, pos2, nonpos):
 @task
 def implicit_positionals(pos1, pos2, nonpos=None):
     pass
+
+@task(optional=['myopt'])
+def optional_values(myopt):
+    pass
